/*
 **************************************************************************
 * Licensed Materials - Property of IBM
 * 5724-M24
 * Copyright IBM Corporation 2005,2011.  All rights reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 **************************************************************************
 * MonitorControls.js
 *
 */

var svgNS = "http://www.w3.org/2000/svg";
var xlinkNS = "http://www.w3.org/1999/xlink";
var notFound = "NOT FOUND";

String.prototype.startsWith = function(str) {return (this.match("^"+str)==str)}

var currentMode; // 0 = Key Performance Indicators;
// 1 = Branching Probabilities;
// 2 = Timing Intervals

function setMode(newMode){
	if (newMode == currentMode) return;
	currentMode = newMode;
	for (var i = 0; i < 3; ++i) {
		var indicator = document.getElementById("indicator" + i);
		if (indicator == null) continue;
		if (i == newMode) {
			indicator.setAttributeNS(null, "visibility", "visible");
		} else {
			indicator.setAttributeNS(null, "visibility", "hidden");
		}
	}
	if (newMode == 0) showKeyPerformanceIndicators();
	if (newMode == 1) showBranchingProbabilities();
	if (newMode == 2) showTimingIntervals();
}

function hide(id) {
	var element = document.getElementById(id);
	if (element) element.setAttributeNS(null, "visibility", "hidden");
}

function show(id) {
	var element = document.getElementById(id);
	if (element) element.setAttributeNS(null, "visibility", "visible");
}

function showKeyPerformanceIndicators(){
	if (currentMode != 0) return;
	hideAll();
	show("kpisControlPanel");
	showKPI(kpiChoices[0]);
}

function showBranchingProbabilities(){
	if (currentMode != 1) return;
	hideAll();
	show("branchingProbsControlPanel");
	show("branchingProbsAll");
}

function showTimingIntervals(){
	if (currentMode != 2) return;
	hideAll();
	show("timingIntervalsControlPanel");
}

function hideAll(){
	// KPIs
	hide("kpisControlPanel");
	hideAllKpiChoices();
	hideAllKpiValues();
	// Branching probabilities
	hide("branchingProbsControlPanel");
	hide("branchingProbsAll");
	// Timing intervals
	hide("timingIntervalsControlPanel");
	hideAllTimingIntervalsChosen();
	hideAllTimingIntervals();
}

// ==================
// KPI visualization
// ==================
var kpiChoices = ["KPI_TotalTime_Average"
                  , "KPI_ExecutionTime_Average"
                  , "KPI_WaitTime_Average"
                  , "KPI_Cost_Average"
                  , "KPI_ResourceCost_Average"
                  , "KPI_LaborCost_Average"
];

function showKPI(kpi){
	if (currentMode != 0) return;
	hideAllKpiChoices();
	hideAllKpiValues();
	show("indicator" + kpi);
	show(kpi);
}

function hideAllKpiChoices(){
	for (var i = 0; i < kpiChoices.length; ++i) {
		hide("indicator" + kpiChoices[i]);
	}
}

function hideAllKpiValues(){
	for (var i = 0; i < kpiChoices.length; ++i) {
		hide(kpiChoices[i]);
	}
}

// ======================================
// Timing intervals visualization
// ======================================

var timingIntervalChoicesShown = 0;

function numberOfTimingIntervals() {
	var element = document.getElementById("timingIntervals");
	if (element == null) return 0;

	var attribute = element.getAttribute("numberOfTimingIntervals");
	if (attribute == null) return 0;

	return attribute;
}

function toggleTimingIntervalMenu() {
	if (currentMode != 2) return;
	timingIntervalChoicesShown = 1-timingIntervalChoicesShown;
	showOrHideTimingIntervalMenu();
}

function showOrHideTimingIntervalMenu() {
	if (currentMode != 2) return;
	if (timingIntervalChoicesShown == 1) show("timingIntervalMenu");
	if (timingIntervalChoicesShown == 0) hide("timingIntervalMenu");
}

function highlightTimingIntervalChoice(n) {
	if (currentMode != 2) return;
	document.getElementById("timingIntervalChoice"+n).setAttributeNS(null, "fill", "#eeeeee");
}

function unHighlightTimingIntervalChoice(n) {
	if (currentMode != 2) return;
	document.getElementById("timingIntervalChoice"+n).setAttributeNS(null, "fill", "#ffffff");
}

function showTimingInterval(n) {
	if (currentMode != 2) return;
	timingIntervalChoicesShown = 0;
	showOrHideTimingIntervalMenu();
	hideAllTimingIntervalsChosen();
	hideAllTimingIntervals();
	show("timingIntervalChosen"+n);
	show("timingInterval"+n);
}

function hideAllTimingIntervalsChosen() {
	for (var t = 1; t <= numberOfTimingIntervals(); t++) {
		hide("timingIntervalChosen"+t);
	}
}

function hideAllTimingIntervals() {
	for (var t = 1; t <= numberOfTimingIntervals(); t++) {
		hide("timingInterval"+t);
	}
}

function showIfMode2(id) {
	if (currentMode == 2) show(id);
}
